@@ -5,7 +5,7 @@ import fnmatch
 import logging
 import re
 
-__version__ = "0.93"
+__version__ = "0.94"
 
 class KotlinStyleChecker:
     def __init__(self):
@@ -50,8 +50,8 @@ class KotlinStyleChecker:
             return str, str
         new_str = str if str[2] == '*' else str[:2] + '*' + str[2:]
         new_str = new_str if new_str[3] == '\n' else new_str[:3] + '\n' + new_str[3:]
-        #new_str = new_str if new_str[-3] == ' ' else new_str[:-2]+' '+new_str[-2:]
-        #new_str = new_str if new_str[-4] == '\n' else new_str[:-3]+'\n'+new_str[-3:]
+        new_str = new_str if new_str[-3] == ' ' else new_str[:-2]+' '+new_str[-2:]
+        new_str = new_str if new_str[-4] == '\n' else new_str[:-3]+'\n'+new_str[-3:]
         #new_str = re.sub('\n[ \t]*\*?[ \t]?', '\n * ', new_str[:-4])+new_str[-4:]
         if '@param' in new_str or '@return' in new_str:
             self.logger.warning("line {}: Avoid using @param and @return tags in comments.".format(line))
